// This is to convert a given 2D point to barycentric UV values and convert barycentric UVs back to a 2D point in a different space
// Usage, 
// var bary_from_gps = new Barycentric( gpsPointA, gpsPointB, gpsPointC )
// var bary_from_image = new Barycentric( imagePointA, imagePointB, imagePointC )
//
// Now to map from one space to another do the following
// uv = bary_from_gps.convert_point_to_uv( long, lat )
// imagexy = bary_from_image.convert_uv_to_point( uv )
// Now image xy contains the point that maps to the gps long/lat passed in

//Tests
//Vector2Double.test();
//Barycentric.test();


function Barycentric(vecA, vecB, vecC)
{
	var m_vecA;
	var m_vecB;
	var m_vecC;
	var m_vecAB;
	var m_vecAC;
	
	this.m_vecA = new Vector2Double(vecA);	
	this.m_vecB = new Vector2Double(vecB);	
	this.m_vecC = new Vector2Double(vecC);	
	this.m_vecAB = new Vector2Double( this.m_vecB );	
	this.m_vecAC = new Vector2Double( this.m_vecC );	
	
	
	
	
	
	this.m_vecAC.subtract(this.m_vecA);
	this.m_vecAB.subtract(this.m_vecA);


	
	
	this.convert_point_to_uv = function(x, y)
	{	
	}
	
	this.convert_point_to_uv = function(vecPIn, y)
	{
		if( typeof(vecPIn) === 'object')
		{
			// Compute vectors        
			var vecAP = new Vector2Double( vecPIn );

			vecAP.subtract(this.m_vecA);
		
			// Compute dot products
			var dot00 = this.m_vecAC.dot(this.m_vecAC);
			var dot01 = this.m_vecAC.dot(this.m_vecAB);
			var dot11 = this.m_vecAB.dot(this.m_vecAB);
			// For point
			var dot02 = this.m_vecAC.dot(vecAP);
			var dot12 = this.m_vecAB.dot(vecAP);
		
			// Compute barycentric coordinates
			var invDenom = 1.0 / ((dot00 * dot11) - (dot01 * dot01));
			var u = ((dot11 * dot02) - (dot01 * dot12)) * invDenom;
			var v = ((dot00 * dot12) - (dot01 * dot02)) * invDenom;
		
			var uv = new Vector2Double( u,v );
		
			return uv;
		}
		else
		{
			// x,y passed in
			temp = new Vector2Double(vecPIn,y);
			return this.convert_point_to_uv(temp);
		}
	}


	
	this.convert_uv_to_point = function (uv)
	{
		var scaledAC = new Vector2Double(this.m_vecAC);
		var scaledAB = new Vector2Double(this.m_vecAB);
		scaledAC.multiply( uv.m_x );
		scaledAB.multiply( uv.m_y );
		
		scaledAC.add(scaledAB);
		
		var result = new Vector2Double(this.m_vecA);
		result.add(scaledAC);
		
		return result;
	}
	
	// Check if point is in the base triangle
	this.test_if_inside_triangle = function (vecPIn)
	{
		var uv = this.convert_point_to_uv( vecPIn );
		
		if( ( uv.m_x > 0 ) && 
			( uv.m_y > 0 ) && 
			((uv.m_x + uv.m_y) < 1) )
		{
			return true;
		}
		// Outside triangle
		return false;
	}	
}


// ------------------------------------------
// Static methods
Barycentric.test = function()
{
	var vec1A = new Vector2Double( 1,1 );
	var vec1B = new Vector2Double( 11,1 );
	var vec1C = new Vector2Double( 1,11 );

	var vec2A = new Vector2Double( 10,10 );
	var vec2B = new Vector2Double( 20,10 );
	var vec2C = new Vector2Double( 10,30 );
	
	var bary1 = new Barycentric( vec1A, vec1B, vec1C );
	var bary2 = new Barycentric( vec2A, vec2B, vec2C );
	
	var vec1P = new Vector2Double( 2,2 );
	var uv = bary1.convert_point_to_uv( vec1P );
	alert( 'UV of bary1 and vec1P u:'+uv.m_x + ' v:'+uv.m_y );
	alert( 'bary1 is in triangle:'+bary1.test_if_inside_triangle( vec1P ) );
	
	var pointInBary2Space = bary2.convert_uv_to_point( uv );
	alert( 'pointInBary2Space x:'+pointInBary2Space.m_x + ' y:'+pointInBary2Space.m_y );
	
	// Now convert back
	var uv2 = bary2.convert_point_to_uv( pointInBary2Space );
	var pointInBary1Space = bary1.convert_uv_to_point( uv2 );
	alert( 'pointInBary1Space x:'+pointInBary1Space.m_x + ' y:'+pointInBary1Space.m_y );
	
}
